@@ -597,9 +597,11 @@ def nth_occ(haystack: Sequence[T], needle: T, n: int) -> Optional[int]:
 
 
 def list_set(ilist: ImmutableList[T], repl_idx: int, new_elem: T) -> ImmutableList[T]:
-    return tuple(
-        [new_elem if idx == repl_idx else elem for idx, elem in enumerate(ilist)]
-    )
+    return ilist[:repl_idx] + (new_elem,) + ilist[repl_idx + 1 :]
+
+
+def list_del(ilist: Sequence[T], del_idx: int) -> Sequence[T]:
+    return ilist[:del_idx] + ilist[del_idx + 1 :]
 
 
 @dataclass(frozen=True)
@@ -793,11 +795,12 @@ def get_isla_resource_file_content(path_to_file: str) -> str:
 
 
 def eassert(
-    expr: T, condition: bool | Callable[[T], bool], msg: str | Callable[[], str] = ""
+    expr: T,
+    condition: bool | Callable[[T], bool],
+    msg: str | Callable[[], str] = "",
 ) -> T:
-    assert condition if isinstance(condition, bool) else condition(expr), (
-        msg if isinstance(msg, str) else msg()
-    )
+    cond = condition if isinstance(condition, bool) else condition(expr)
+    assert cond, msg if isinstance(msg, str) else msg()
     return expr
 
 
